#
# spec file for package fdupes
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# Upstream calls this version 1.6.1, but that version number is *lower* than
# previously released ones, like 1.51, so we mangle the number to keep
# continuity: https://github.com/adrianlopezroche/fdupes/issues/74.
%global upstream_version 1.6.1

Name:           fdupes
Version:        1.61
Release:        lp152.3.114
Summary:        Identifying or deleting duplicate files
License:        MIT
Group:          Productivity/Archiving/Compression
Url:            https://github.com/adrianlopezroche/fdupes
Source0:        https://github.com/adrianlopezroche/fdupes/archive/v%{upstream_version}.tar.gz#/%{name}-%{upstream_version}.tar.gz
Source1:        macros.fdupes
#PATCH-FIX-SUSE: fix patch according distro's needs
Patch0:         fdupes-makefile.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
FDUPES is a program for identifying or deleting duplicate files
residing within specified directories.

%prep
%setup -q -n %{name}-%{upstream_version}
%patch0

%build
make %{?_smp_mflags} COMPILER_OPTIONS="%{optflags}"

%install
install -D -m755 %{name} %{buildroot}%{_bindir}/%{name}
install -D -m644 %{name}.1 %{buildroot}%{_mandir}/man1/%{name}.1
install -D -m644 %{SOURCE1} %{buildroot}%{_sysconfdir}/rpm/macros.%{name}

%check
./%{name} testdir
./%{name} --omitfirst testdir
./%{name} --recurse testdir
./%{name} --size testdir

%files
%defattr(-, root, root)
%doc CHANGES
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1*
%config %{_sysconfdir}/rpm/macros.%{name}

%changelog
* Fri Dec 16 2016 psimons@suse.com
- We cannot update from fdupes 1.51 to 1.6.1. That "downgrade"
  works okay'ish for Tumbleweed because we can replace the old
  package with the new one, but in SLE this is not possible. We
  asked upstream to please release a "2.0" version to remedy these
  issues (https://github.com/adrianlopezroche/fdupes/issues/74),
  but he does not respond. Therefore, we'll call this version 1.61,
  ignoring upstreams change in the versioning scheme.
* Mon Dec  5 2016 psimons@suse.com
- Upstream has changed their versioning scheme after version 1.51.
  Unfortunately, the new version 1.6.x won't be recognized as
  "newer" by zypper. This commit adds appropriate "provides" and
  "obsoletes" attributes to the spec file to remedy that issue.
* Fri Nov  4 2016 psimons@suse.com
- Drop 50_bts284274_hardlinkreplace.dpatch. The --linkhard option
  added by this patch has an implementation bug that can cause data
  loss. https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=677419
  has more details.
* Fri Nov  4 2016 psimons@suse.com
- Update to version 1.6.1. The following patches have been applied
  upstream and were dropped:
  * 0001-restore-pristine-code.patch
  * 0002-Added-to-escape-minus-signs-in-manpage-lintian-warni.patch
  * 0003-Fix-a-typo-in-a-manpage-bts353789.patch
  * 0005-add-summarize-to-manpage-bts481809.patch
  * 0006-add-nohidden-support-bts511702.patch
  * 0007-Disambiguate-the-options-recurse-and-recurse-bts5371.patch
  * 0008-speedup-the-file-compare.patch
  * 0009-glibc-endianness-check-in-md5.patch
  * 0010-add-permissions-mode.patch
  * 0011-add-an-option-to-sort-duplicate-files-by-name.patch
- 50_bts284274_hardlinkreplace.dpatch had to be refreshed.
* Tue Aug  4 2015 tchvatal@suse.com
- By default relink hardlinks too, should fix bnc#940296
* Mon Aug  3 2015 tchvatal@suse.com
- Update to upstream git repo on github
- Refresh patches:
  * fdupes-makefile.patch
  * 0008-speedup-the-file-compare.patch
  * 0010-add-permissions-mode.patch
  * 0011-add-an-option-to-sort-duplicate-files-by-name.patch
  * 50_bts284274_hardlinkreplace.dpatch
- Upstreamed patch:
  * 0004-Large-file-support-for-2GB-files-bts447601.patch
- Remove whitespace from fdupes.macros file
- Cleanup with spec-cleaner
  - Obey rpm-opt-flags
  - run test phase
* Sun Dec 21 2014 bwiedemann@suse.com
- add -L (--linkhard) option
  add 50_bts284274_hardlinkreplace.dpatch
* Tue Apr 29 2014 stefan.bruens@rwth-aachen.de
- sort the output of fdupes by filename to make it deterministic
  for parallel builds
  * 0011-add-an-option-to-sort-duplicate-files-by-name.patch
* Tue Oct 16 2012 mvyskocil@suse.com
- update to 1.5.0-PR2
  * new "--summarize" option
  * new  "--recurse:" selective recursion option
  * new "--noprompt" option for totally automated deletion of
  duplicate files.
  * sorts duplicates (old to new) for consistent order when
  listing or deleteing duplicate files.
  * tests for early matching of files, which should help speed up
  the matching process when large files are involved.
  * warns whenever a file cannot be deleted.
  * bugfixes (proper file closing, zero-length files, ...)
- drop the fdupes-sort-output.diff (upstream uses mtime based)
- rename and rebase fdupes-speedup.patch to 0008-speedup-the-compare.patch
- rename and rebase fdupes-endianness.patch to
  0009-glibc-endianness-check-in-md5.patch
- add -p/--permissions switch so files with different permissions or uid/gid
  are not considered as duplicates (bnc#784670)
  * this mode is a default one for fdupes macro
  0010-add-permissions-mode.patch
- imported several fixes from Debian
  * 0001-restore-pristine-code.patch - some common code fixes, partly obsoletes
    speedup patch
  * manual page fixes
    0002-Added-to-escape-minus-signs-in-manpage-lintian-warni.patch
    0003-Fix-a-typo-in-a-manpage-bts353789.patch
    0005-add-summarize-to-manpage-bts481809.patch
    0006-add-nohidden-support-bts511702.patch
    0007-Disambiguate-the-options-recurse-and-recurse-bts5371.patch
  * 0004-Large-file-support-for-2GB-files-bts447601.patch - large file support
* Sun Mar 25 2012 behrisch@users.sf.net
- added "which" requirement for red hat distros
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Wed Oct  5 2011 uli@suse.com
- cross-build workaround: fake gcc script to work around build
  system not honoring CC
* Sun Sep 18 2011 jengelh@medozas.de
- Apply packaging guidelines (remove redundant/obsolete
  tags/sections from specfile, etc.)
* Mon Feb 15 2010 mvyskocil@suse.cz
- fix bnc#406825: speedup fdupes
  * fdupes-speedup.patch fixes some performance gaps in code
  * fdupes-endianness.patch speedups the built in md5 on little endian machines
* Wed Aug 26 2009 mls@suse.de
- make patch0 usage consistent
* Thu Jan 15 2009 coolo@suse.de
- sort the output of fdupes to make it deterministic
* Thu Sep  6 2007 mls@suse.de
- do not hardlink empty files in %%fdupes macro
* Wed Sep  5 2007 nadvornik@suse.cz
- support filenames with spaces in %%fdupes macro [#307727]
* Tue May 15 2007 coolo@suse.de
- add an RPM macro to make use of it in spec files
* Thu Nov 16 2006 dmueller@suse.de
- Initial package (1.40)
